@@ -4,14 +4,15 @@ from django.http import JsonResponse
 from django.utils.decorators import method_decorator
 from django.views import View
 from django.views.decorators.csrf import csrf_exempt
+from django.conf import settings
 
-from .config import (EDITORJS_IMAGE_NAME, EDITORJS_IMAGE_NAME_ORIGINAL,
-                     EDITORJS_IMAGE_NAME_POSTFIX, EDITORJS_IMAGE_UPLOAD_PATH)
+from .config import (IMAGE_NAME, IMAGE_NAME_ORIGINAL, IMAGE_NAME_POSTFIX,
+                     IMAGE_UPLOAD_PATH)
 from .utils import storage
 
 
 class ImageUploadView(View):
-    http_method_names = ["post"]
+    http_method_names = ["post", "delete"]
 
     @method_decorator(csrf_exempt)
     def dispatch(self, request, *args, **kwargs):
@@ -39,17 +40,33 @@ class ImageUploadView(View):
 
             filename, extension = os.path.splitext(the_file.name)
 
-            if EDITORJS_IMAGE_NAME_ORIGINAL:
-                filename = filename + EDITORJS_IMAGE_NAME_POSTFIX
+            if IMAGE_NAME_ORIGINAL:
+                filename = filename + IMAGE_NAME_POSTFIX
             else:
-                filename = EDITORJS_IMAGE_NAME
+                filename = IMAGE_NAME
 
             filename += extension
 
             path = storage.save(
-                os.path.join(EDITORJS_IMAGE_UPLOAD_PATH, filename), the_file
+                os.path.join(IMAGE_UPLOAD_PATH, filename), the_file
             )
             link = storage.url(path)
 
             return JsonResponse({'success': 1, 'file': {"url": link}})
         return JsonResponse({'success': 0})
+
+    def delete(self, request):
+        path_file = request.GET.get('pathFile')
+
+        if not path_file:
+            return JsonResponse({'success': 0, 'message': 'Parameter "pathFile" Not Found'})
+
+        base_dir = getattr(settings, "BASE_DIR", '')
+        path_file = f'{base_dir}{path_file}'
+
+        if not os.path.isfile(path_file):
+            return JsonResponse({'success': 0, 'message': 'File Not Found'})
+
+        os.remove(path_file)
+
+        return JsonResponse({'success': 1})
